@@ -9,9 +9,10 @@ import click
 
 from ..client.gas import DatasetClientType
 from .tbrn import TBRN, TBRNType
-from .utility import ContextInfo, error, get_dataset_client, get_gas
+from .utility import ContextInfo, error, exception_handler, get_dataset_client, get_gas
 
 
+@exception_handler
 def _implement_tag(obj: ContextInfo, tbrn: str, name: str, is_delete: bool) -> None:
     info = TBRN(tbrn=tbrn)
 
