@@ -20,6 +20,7 @@ from typing_extensions import Literal
 
 from ..dataset import Dataset, FusionDataset
 from ..exception import DatasetTypeError, OperationError, ResourceNotExistError
+from ..utility import Deprecated
 from .cloud_storage import CloudClient
 from .dataset import DatasetClient, FusionDatasetClient
 from .lazy import PagingList
@@ -33,6 +34,7 @@ DatasetClientType = Union[DatasetClient, FusionDatasetClient]
 logger = logging.getLogger(__name__)
 
 DEFAULT_BRANCH = "main"
+DEFAULT_IS_PUBLIC = False
 
 
 class GAS:
@@ -70,11 +72,19 @@ class GAS:
         commit_id = info["commitId"]
         default_branch = info["defaultBranch"]
         dataset_alias = info["alias"]
+        is_public = info["isPublic"]
 
         status = Status(default_branch, commit_id=commit_id)
 
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, dataset_id, self, status=status, alias=dataset_alias)
+        return ReturnType(
+            name,
+            dataset_id,
+            self,
+            status=status,
+            alias=dataset_alias,
+            is_public=is_public,
+        )
 
     def _get_dataset(self, name: str) -> Dict[str, Any]:
         """Get the information of the TensorBay dataset with the input name.
@@ -180,6 +190,123 @@ class GAS:
             128,
         )
 
+    def delete_storage_config(self, name: str) -> None:
+        """Delete a storage config in TensorBay.
+
+        Arguments:
+            name: Name of the storage config, unique for a team.
+
+        """
+        self._client.open_api_do("DELETE", f"storage-configs/{name}")
+
+    def create_oss_storage_config(
+        self,
+        name: str,
+        file_path: str,
+        *,
+        endpoint: str,
+        accesskey_id: str,
+        accesskey_secret: str,
+        bucket_name: str,
+    ) -> CloudClient:
+        """Create an oss auth storage config.
+
+        Arguments:
+            name: The required auth storage config name.
+            file_path: dataset storage path of the bucket.
+            endpoint: endpoint of the oss.
+            accesskey_id: accesskey_id of the oss.
+            accesskey_secret: accesskey_secret of the oss.
+            bucket_name: bucket_name of the oss.
+
+        Returns:
+            The cloud client of this dataset.
+
+        """
+        post_data = {
+            "name": name,
+            "filePath": file_path,
+            "endpoint": endpoint,
+            "accesskeyId": accesskey_id,
+            "accesskeySecret": accesskey_secret,
+            "bucketName": bucket_name,
+        }
+
+        self._client.open_api_do("POST", "storage-configs/oss", json=post_data)
+        return CloudClient(name, self._client)
+
+    def create_s3_storage_config(
+        self,
+        name: str,
+        file_path: str,
+        *,
+        endpoint: str,
+        accesskey_id: str,
+        accesskey_secret: str,
+        bucket_name: str,
+    ) -> CloudClient:
+        """Create a s3 auth storage config.
+
+        Arguments:
+            name: The required auth storage config name.
+            file_path: dataset storage path of the bucket.
+            endpoint: endpoint of the s3.
+            accesskey_id: accesskey_id of the s3.
+            accesskey_secret: accesskey_secret of the s3.
+            bucket_name: bucket_name of the s3.
+
+        Returns:
+            The cloud client of this dataset.
+
+        """
+        post_data = {
+            "name": name,
+            "filePath": file_path,
+            "endpoint": endpoint,
+            "accesskeyId": accesskey_id,
+            "accesskeySecret": accesskey_secret,
+            "bucketName": bucket_name,
+        }
+
+        self._client.open_api_do("POST", "storage-configs/s3", json=post_data)
+        return CloudClient(name, self._client)
+
+    def create_azure_storage_config(
+        self,
+        name: str,
+        file_path: str,
+        *,
+        account_type: str,
+        account_name: str,
+        account_key: str,
+        container_name: str,
+    ) -> CloudClient:
+        """Create an azure auth storage config.
+
+        Arguments:
+            name: The required auth storage config name.
+            file_path: dataset storage path of the bucket.
+            account_type: account type of azure, only support "China" and "Global".
+            account_name: account name of the azure.
+            account_key: account key of the azure.
+            container_name: container name of the azure.
+
+        Returns:
+            The cloud client of this dataset.
+
+        """
+        post_data = {
+            "name": name,
+            "filePath": file_path,
+            "accesskeyId": account_name,
+            "accesskeySecret": account_key,
+            "containerName": container_name,
+            "accountType": account_type,
+        }
+
+        self._client.open_api_do("POST", "storage-configs/azure", json=post_data)
+        return CloudClient(name, self._client)
+
     def get_cloud_client(self, name: str) -> CloudClient:
         """Get a cloud client used for interacting with cloud platform.
 
@@ -188,6 +315,7 @@ class GAS:
 
         Returns:
             The cloud client of this dataset.
+
         """
         self.get_auth_storage_config(name)
         return CloudClient(name, self._client)
@@ -198,7 +326,7 @@ class GAS:
         name: str,
         is_fusion: Literal[False] = False,
         *,
-        region: Optional[str] = None,
+        config_name: Optional[str] = None,
         alias: str = "",
     ) -> DatasetClient:
         ...
@@ -209,7 +337,7 @@ class GAS:
         name: str,
         is_fusion: Literal[True],
         *,
-        region: Optional[str] = None,
+        config_name: Optional[str] = None,
         alias: str = "",
     ) -> FusionDatasetClient:
         ...
@@ -220,7 +348,7 @@ class GAS:
         name: str,
         is_fusion: bool = False,
         *,
-        region: Optional[str] = None,
+        config_name: Optional[str] = None,
         alias: str = "",
     ) -> DatasetClientType:
         ...
@@ -230,7 +358,7 @@ class GAS:
         name: str,
         is_fusion: bool = False,
         *,
-        region: Optional[str] = None,  # beijing, hangzhou, shanghai
+        config_name: Optional[str] = None,
         alias: str = "",
     ) -> DatasetClientType:
         """Create a TensorBay dataset with given name.
@@ -238,8 +366,7 @@ class GAS:
         Arguments:
             name: Name of the dataset, unique for a user.
             is_fusion: Whether the dataset is a fusion dataset, True for fusion dataset.
-            region: Region of the dataset to be stored,
-                only support "beijing", "hangzhou", "shanghai", default is "shanghai".
+            config_name: The auth storage config name.
             alias: Alias of the dataset, default is "".
 
         Returns:
@@ -253,21 +380,29 @@ class GAS:
             "type": int(is_fusion),  # normal dataset: 0, fusion dataset: 1
             "alias": alias,
         }
-        if region:
-            post_data["region"] = region
+        if config_name is not None:
+            post_data["configName"] = config_name
 
         status = Status(DEFAULT_BRANCH, commit_id=ROOT_COMMIT_ID)
 
         response = self._client.open_api_do("POST", "", json=post_data)
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, response.json()["id"], self, status=status, alias=alias)
+        return ReturnType(
+            name,
+            response.json()["id"],
+            self,
+            status=status,
+            alias=alias,
+            is_public=DEFAULT_IS_PUBLIC,
+        )
 
+    @Deprecated(since="1.12.0", removed_in="1.15.0", substitute="GAS.create_dataset")
     def create_auth_dataset(
         self,
         name: str,
-        config_name: str,
-        *,
         is_fusion: bool = False,
+        *,
+        config_name: Optional[str] = None,
         alias: str = "",
     ) -> DatasetClientType:
         """Create a TensorBay dataset with given name in auth cloud storage.
@@ -277,8 +412,8 @@ class GAS:
 
         Arguments:
             name: Name of the dataset, unique for a user.
-            config_name: The auth storage config name.
             is_fusion: Whether the dataset is a fusion dataset, True for fusion dataset.
+            config_name: The auth storage config name.
             alias: Alias of the dataset, default is "".
 
         Returns:
@@ -287,18 +422,7 @@ class GAS:
             and the status of dataset client is "commit".
 
         """
-        post_data = {
-            "name": name,
-            "type": int(is_fusion),  # normal dataset: 0, fusion dataset: 1
-            "configName": config_name,
-            "alias": alias,
-        }
-
-        status = Status(DEFAULT_BRANCH, commit_id=ROOT_COMMIT_ID)
-
-        response = self._client.open_api_do("POST", "", json=post_data)
-        ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, response.json()["id"], self, status=status, alias=alias)
+        return self.create_dataset(name, is_fusion, config_name=config_name, alias=alias)
 
     @overload
     def get_dataset(self, name: str, is_fusion: Literal[False] = False) -> DatasetClient:
@@ -335,13 +459,21 @@ class GAS:
         commit_id = info["commitId"]
         default_branch = info["defaultBranch"]
         dataset_alias = info["alias"]
+        is_public = info["isPublic"]
 
         status = Status(default_branch, commit_id=commit_id)
 
         if is_fusion != type_flag:
             raise DatasetTypeError(dataset_name=name, is_fusion=type_flag)
         ReturnType: Type[DatasetClientType] = FusionDatasetClient if is_fusion else DatasetClient
-        return ReturnType(name, dataset_id, self, status=status, alias=dataset_alias)
+        return ReturnType(
+            name,
+            dataset_id,
+            self,
+            status=status,
+            alias=dataset_alias,
+            is_public=is_public,
+        )
 
     def list_dataset_names(self) -> PagingList[str]:
         """List names of all TensorBay datasets.
@@ -354,19 +486,29 @@ class GAS:
             lambda offset, limit: self._generate_dataset_names(None, offset, limit), 128
         )
 
-    def update_dataset(self, name: str, *, alias: Optional[str] = None) -> None:
+    def update_dataset(
+        self,
+        name: str,
+        *,
+        alias: Optional[str] = None,
+        is_public: Optional[bool] = None,
+    ) -> None:
         """Update a TensorBay Dataset.
 
         Arguments:
             name: Name of the dataset, unique for a user.
             alias: New alias of the dataset.
+            is_public: Whether the dataset is public.
 
         """
         dataset_id = self._get_dataset(name)["id"]
-        patch_data = {}
+        patch_data: Dict[str, Any] = {}
         if alias is not None:
             patch_data["alias"] = alias
 
+        if is_public is not None:
+            patch_data["isPublic"] = is_public
+
         if patch_data:
             self._client.open_api_do("PATCH", "", dataset_id, json=patch_data)
 
