@@ -30,13 +30,13 @@ from typing import TYPE_CHECKING, Any, Callable, Dict, Generator, Iterable, Opti
 
 import filetype
 from requests_toolbelt import MultipartEncoder
-from ulid import from_timestamp
+from ulid import ULID, from_timestamp
 
 from ..dataset import AuthData, Data, Frame, RemoteData
 from ..exception import FrameError, InvalidParamsError, OperationError, ResponseError
 from ..label import Label
 from ..sensor.sensor import Sensor, Sensors
-from ..utility import Disable, FileMixin, chunked, locked
+from ..utility import FileMixin, chunked, locked
 from .lazy import PagingList
 from .requests import config
 from .status import Status
@@ -307,27 +307,6 @@ class SegmentClientBase:  # pylint: disable=too-many-instance-attributes
         """
         return self._status
 
-    @Disable(since="v1.6.0", enabled_in="v1.12.0", reason="TensorBay server refactor")
-    def delete_data(self, remote_paths: Union[str, Iterable[str]]) -> None:
-        """Delete data of a segment in a certain commit with the given remote paths.
-
-        Arguments:
-            remote_paths: The remote paths of data in a segment.
-
-        """
-        self._status.check_authority_for_draft()
-
-        all_paths = iter((remote_paths,)) if isinstance(remote_paths, str) else iter(remote_paths)
-
-        for request_remote_paths in chunked(all_paths, 128):
-            delete_data: Dict[str, Any] = {
-                "segmentName": self.name,
-                "remotePaths": request_remote_paths,
-            }
-            delete_data.update(self._status.get_status_info())
-
-            self._client.open_api_do("DELETE", "data", self._dataset_id, json=delete_data)
-
 
 class SegmentClient(SegmentClientBase):
     """This class defines :class:`SegmentClient`.
@@ -661,6 +640,22 @@ class SegmentClient(SegmentClientBase):
             lambda offset, limit: self._generate_data(url_getters, offset, limit), 128
         )
 
+    def delete_data(self, remote_path: str) -> None:
+        """Delete data of a segment in a certain commit with the given remote paths.
+
+        Arguments:
+            remote_path: The remote path of data in a segment.
+
+        """
+        self._status.check_authority_for_draft()
+        delete_data: Dict[str, Any] = {
+            "segmentName": self.name,
+            "remotePath": remote_path,
+        }
+        delete_data.update(self._status.get_status_info())
+
+        self._client.open_api_do("DELETE", "data", self._dataset_id, json=delete_data)
+
     def list_urls(self) -> PagingList[str]:
         """List the data urls in this segment.
 
@@ -837,6 +832,22 @@ class FusionSegmentClient(SegmentClientBase):
         urls = self.list_urls()
         return PagingList(lambda offset, limit: self._generate_frames(urls, offset, limit), 128)
 
+    def delete_frame(self, frame_id: Union[str, ULID]) -> None:
+        """Delete a frame of a segment in a certain commit with the given frame id.
+
+        Arguments:
+            frame_id: The id of a frame in a segment.
+
+        """
+        self._status.check_authority_for_draft()
+        delete_data: Dict[str, Any] = {
+            "segmentName": self.name,
+            "frameId": str(frame_id),
+        }
+        delete_data.update(self._status.get_status_info())
+
+        self._client.open_api_do("DELETE", "frames", self._dataset_id, json=delete_data)
+
     def list_urls(self) -> PagingList[Dict[str, str]]:
         """List the data urls in this segment.
 
