@@ -15,43 +15,35 @@ corresponding to different types of labels.
 .. table:: subcatalog classes
    :widths: auto
 
-   ==================================   ==================================================
-   subcatalog classes                   explaination
-   ==================================   ==================================================
-   :class:`.ClassificationSubcatalog`   subcatalog for classification type of label
-   :class:`.Box2DSubcatalog`            subcatalog for 2D bounding box type of label
-   :class:`.Box3DSubcatalog`            subcatalog for 3D bounding box type of label
-   :class:`.Keypoints2DSubcatalog`      subcatalog for 2D polygon type of label
-   :class:`.Polygon2DSubcatalog`        subcatalog for 2D polyline type of label
-   :class:`.Polyline2DSubcatalog`       subcatalog for 2D keypoints type of label
-   :class:`.SentenceSubcatalog`         subcatalog for transcripted sentence type of label
-   ==================================   ==================================================
+   ===================================   ==================================================
+   subcatalog classes                    explaination
+   ===================================   ==================================================
+   :class:`.ClassificationSubcatalog`    subcatalog for classification type of label
+   :class:`.Box2DSubcatalog`             subcatalog for 2D bounding box type of label
+   :class:`.Box3DSubcatalog`             subcatalog for 3D bounding box type of label
+   :class:`.Keypoints2DSubcatalog`       subcatalog for 2D keypoints type of label
+   :class:`.PolygonSubcatalog`           subcatalog for polygon type of label
+   :class:`.Polyline2DSubcatalog`        subcatalog for 2D polyline type of label
+   :class:`.MultiPolygonSubcatalog`      subcatalog for multiple polygon type of label
+   :class:`.RLESubcatalog`               subcatalog for rle mask type of label
+   :class:`.MultiPolyline2DSubcatalog`   subcatalog for 2D multiple polyline type of label
+   :class:`.SentenceSubcatalog`          subcatalog for transcripted sentence type of label
+   ===================================   ==================================================
 
 """
 
 from functools import partial
-from typing import Any, Dict, Type, TypeVar, Union
+from typing import Any, Dict, Iterator, Type, TypeVar
 
-from ..label import LabelType
 from ..utility import AttrsMixin, ReprMixin, ReprType, attr, common_loads, upper
 from .label_box import Box2DSubcatalog, Box3DSubcatalog
 from .label_classification import ClassificationSubcatalog
 from .label_keypoints import Keypoints2DSubcatalog
-from .label_polygon import Polygon2DSubcatalog
-from .label_polyline import Polyline2DSubcatalog
+from .label_mask import InstanceMaskSubcatalog, PanopticMaskSubcatalog, SemanticMaskSubcatalog
+from .label_polygon import MultiPolygonSubcatalog, PolygonSubcatalog, RLESubcatalog
+from .label_polyline import MultiPolyline2DSubcatalog, Polyline2DSubcatalog
 from .label_sentence import SentenceSubcatalog
 
-Subcatalogs = Union[
-    ClassificationSubcatalog,
-    Box2DSubcatalog,
-    Box3DSubcatalog,
-    Polygon2DSubcatalog,
-    Polyline2DSubcatalog,
-    Keypoints2DSubcatalog,
-    SentenceSubcatalog,
-]
-
-
 _ERROR_MESSAGE = "The '{attr_name}' subcatalog is not provided in this dataset"
 _attr = partial(attr, is_dynamic=True, key=upper, error_message=_ERROR_MESSAGE)
 
@@ -89,22 +81,28 @@ class Catalog(ReprMixin, AttrsMixin):
     _T = TypeVar("_T", bound="Catalog")
 
     _repr_type = ReprType.INSTANCE
-    _repr_attrs = tuple(label_type.value for label_type in LabelType)
     _repr_maxlevel = 2
 
     classification: ClassificationSubcatalog = _attr()
     box2d: Box2DSubcatalog = _attr()
     box3d: Box3DSubcatalog = _attr()
-    polygon2d: Polygon2DSubcatalog = _attr()
+    polygon: PolygonSubcatalog = _attr()
     polyline2d: Polyline2DSubcatalog = _attr()
+    multi_polyline2d: MultiPolyline2DSubcatalog = _attr()
     keypoints2d: Keypoints2DSubcatalog = _attr()
+    multi_polygon: MultiPolygonSubcatalog = _attr()
+    rle: RLESubcatalog = _attr()
     sentence: SentenceSubcatalog = _attr()
+    semantic_mask: SemanticMaskSubcatalog = _attr()
+    instance_mask: InstanceMaskSubcatalog = _attr()
+    panoptic_mask: PanopticMaskSubcatalog = _attr()
 
     def __bool__(self) -> bool:
-        for label_type in LabelType:
-            if hasattr(self, label_type.value):
-                return True
-        return False
+        return any(hasattr(self, key) for key in self._attrs_fields)
+
+    @property
+    def _repr_attrs(self) -> Iterator[str]:  # type: ignore[override]
+        yield from self._attrs_fields
 
     @classmethod
     def loads(cls: Type[_T], contents: Dict[str, Any]) -> _T:
